@@ -12,5 +12,11 @@ pub use get_exponent_value::*;
 mod ldexp;
 pub use ldexp::*;
 
+mod max;
+pub use max::*;
+
+mod min;
+pub use min::*;
+
 mod truncate;
 pub use truncate::*;
